#Roo All.Vigilance Behaviour Data
#Linear Mixed Effects Model Final version, all variables included

vigilance <- read.csv(file.choose())    # Choose full data set.csv

library(lme4)

str(vigilance)

dat1 <- vigilance[, - (45:49)]
dat2 <- dat1[, - (30:43)]
dat3 <- dat2[, - (13:16)]
dat3$Group.ID <- NULL
dat3$No..females <- NULL
dat3$No..males <- NULL
dat3$ID <- NULL
dat3$No..groups <- NULL
dat3$Individual <- NULL
dat3$Time <- NULL
dat3$Date <- NULL
dat3$Location <- NULL
dat3$Group.size <- NULL
dat3$Position.in.group <- NULL

str(dat3)

library(partykit)
t1 <- ctree(Vigilance ~ . , data=dat3)
plot(t1)

pairs(dat3)

with(dat3, cor(Mob.size, Group.size), use="all.obs")
#0.6234293
with(dat3, cor(Mob.size, Site), use="all.obs")
with(dat3, cor(Mob.size, HPD16), use="all.obs")
with(dat3, cor(HPD16, Site), use="all.obs")

with(dat3, cor(Mob.size, Vigilance), use="all.obs")
with(dat3, cor(Group.size, Vigilance), use="all.obs")

## Do the same with anti pred

dat1a <- vigilance[, - (46:49)]
dat2a <- dat1a[, - (30:44)]
dat3a <- dat2a[, - (13:16)]
dat3a$Group.ID <- NULL
dat3a$No..females <- NULL
dat3a$No..males <- NULL
dat3a$ID <- NULL
dat3a$No..groups <- NULL
dat3a$Individual <- NULL
dat3a$Time <- NULL
dat3a$Date <- NULL
dat3a$Location <- NULL
dat3a$Group.size <- NULL
dat3a$Position.in.group <- NULL

str(dat3a)

library(partykit)
t2 <- ctree(AP.Vigilance ~ . , data=dat3a)
plot(t2)

# Check that the dataframe has been read correctly

vigilance         # This prints all of the data in dframe1
names (vigilance)   # This provides a list of variable names for dframe1
summary (vigilance)

vigilance$All.Vigilance <- as.numeric (vigilance$Vigilance) # change format of vigilance duration data
vigilance$Distance.to.cover <- as.integer(vigilance$Distance.to.cover)
vigilance$Site <- as.factor(vigilance$Site)
vigilance$Region <- as.factor(vigilance$Region)

####################################################

### Create graph for landuse and ap or social split

vig.type <- read.csv(file.choose())    

library(ggplot2)

ggplot(data=vig.type, aes(x=Landuse, y=Vigilance, fill=Type)) +
  geom_bar(stat="identity", position=position_dodge()) +
  labs(x="Land use", y="Total time spent vigilance (sec)")

ggplot(data=vig.type, aes(x=Landuse, y=Vigilance, fill=Type)) +
  facet_wrap(~Season)+
  geom_bar(stat="identity", position="dodge", colour="black") +
  labs(x="Land use", y="Total time spent vigilance (sec)")+ 
  theme(legend.title = element_blank())

#######################################


########## Create graph for vigilance with chewing

chew <- read.csv(file.choose()) ## Open vigilance chewing.csv

ggplot(data=chew, aes(x=Type, y=Total, fill=Chewing, alpha=Season)) +
  geom_bar(stat="identity", position="dodge", colour="black") +
  labs(x="Land use and Region", y="Total time spent vigilance (sec)")+ 
  theme(legend.title = element_blank())


## These are final 4 graphs
ggplot(data=chew, aes(x=Season, y=Total, fill=Chewing)) +
  facet_wrap(~Type)+
  geom_bar(stat="identity", position="dodge", colour="black") +
  labs(x="Season", y="Total time spent vigilance (sec)")+ 
  theme(legend.title = element_blank())


##################################################

# Boxplots of vigilance time * factors

boxplot(All.Vigilance ~ Region, vigilance)
boxplot(All.Vigilance ~ Landuse, vigilance)
boxplot(All.Vigilance ~ Sex, vigilance)

boxplot(All.Vigilance ~ Region*Landuse,col=c("white", "lightgray"), vigilance)
boxplot(All.Vigilance ~ Season*Region, col=c("white", "lightgray"), vigilance) # No difference in SEQ, Winter in ACT higher

boxplot(AP.Vigilance ~ Season*Region, col=c("white", "lightgray"), vigilance) # No difference in SEQ, Winter in ACT higher

boxplot(All.Vigilance ~ Sex*Region, col=c("white", "lightgray"), vigilance)
plot(vigilance$Mob.size, vigilance$All.Vigilance)
plot(vigilance$Group.size, vigilance$All.Vigilance)

boxplot(All.Vigilance ~ Season, vigilance)
boxplot(AP.Vigilance ~ Season, vigilance)

hist(vigilance$All.Vigilance)

hist(sqrt(vigilance$All.Vigilance)) #sqrt transformation needed to appear normal
qqnorm(sqrt(vigilance$All.Vigilance))
qqline(sqrt(vigilance$All.Vigilance))

hist(sqrt(vigilance$AP.Vigilance))
qqnorm(sqrt(vigilance$AP.Vigilance))
qqline(sqrt(vigilance$AP.Vigilance))

hist(sqrt(vigilance$Vigilant.acts))
qqnorm(sqrt(vigilance$Vigilant.acts))
qqline(sqrt(vigilance$Vigilant.acts))


#######################################################################################################

####### Linear mixed effect model ########

### Model to test for effects on All vigilance

# with transformations


dat3$vig.edit <- sqrt(dat3$Vigilance)

dat3$Region <- as.factor(dat3$Region) ## Region 1 is SEQ

hist(dat3$Vigilance)
hist(sqrt(dat3$Vigilance))

summary(m0 <- lmer(vig.edit ~ Mob.size + Sex + Landuse + RF2day + HPD16 + Distance.to.cover + Season*Region  +(1|Site), 
                  data=dat3))

drop1(m0, test = "Chi")
m1 <- update(m0, ~ . - Mob.size)
anova(m1, m0)
summary(m1)
drop1(m1, test = "Chi")
m2 <- update(m1, ~ . - RF2day)
anova(m1, m2)
summary(m2)
drop1(m2, test = "Chi")
m3 <- update(m2, ~ . -Landuse)
anova(m3, m2)
summary(m3) 
drop1(m3, test = "Chi")
m4 <- update(m3, ~ . -HPD16)
anova(m4, m3)
summary(m4)##### FINAL
drop1(m4, test="Chi")
m5 <- update(m4, ~ . -Distance.to.cover)
anova(m5,m4)
summary(m5)


#############################################

#### Separate into each region and run model for each one

SEQ <- subset(dat3, dat3$Region=="1")
ACT <- subset(dat3, dat3$Region=="2")

########## Model of all vigilance in SEQ

hist(SEQ$Vigilance)
hist(sqrt(SEQ$Vigilance))

seqm0 <- lmer(vig.edit ~ Mob.size + Sex + Landuse + RF2day + HPD16 + Distance.to.cover + Season +(1|Site), 
              data=SEQ)
summary(seqm0)

drop1(seqm0, test = "Chi")
seqm1 <- update(seqm0, ~ . -HPD16)
anova(seqm1, seqm0)
summary(seqm1)
drop1(seqm1, test = "Chi")
seqm2 <- update(seqm1, ~ . - Landuse)
anova( seqm2, seqm1)
summary(seqm2)
drop1(seqm2, test = "Chi")
seqm3 <- update(seqm2, ~ . - Season)
anova(seqm3, seqm2)
summary(seqm3)
drop1(seqm3, test = "Chi")
seqm4 <- update(seqm3, ~ . - Mob.size)
anova(seqm4, seqm3)
summary(seqm4) #### This is final model
drop1(seqm4, test = "Chi")
seqm5 <- update(seqm4, ~ . - RF2day)
anova(seqm5, seqm4)
summary(seqm5)

########## Model of all vigilance in ACT

hist(ACT$Vigilance)
hist(sqrt(ACT$Vigilance))

actm0 <- lmer(vig.edit ~ Mob.size + Sex + Landuse + RF2day + HPD16 + Distance.to.cover + Season +(1|Site), 
              data=ACT)
summary(actm0)

drop1(actm0, test = "Chi")
actm1 <- update(actm0, ~ . -HPD16)
anova(actm1, actm0)
summary(actm1)
drop1(actm1, test = "Chi")
actm2 <- update(actm1, ~ . - Mob.size)
anova( actm2, actm1)
summary(actm2)
drop1(actm2, test = "Chi")
actm3 <- update(actm2, ~ . - Sex)
anova(actm3, actm2)
summary(actm3)
drop1(actm3, test = "Chi")
actm4 <- update(actm3, ~ . - Distance.to.cover)
anova(actm4, actm3)
summary(actm4)
drop1(actm4, test = "Chi")
actm5 <- update(actm4, ~ . - RF2day)
anova(actm5, actm4)
summary(actm5) #### This is the final model  #### Landuse is significant in ACT
drop1(actm5, test = "Chi")
actm6 <- update(actm5, ~ . - Landuse)
anova(actm6, actm5)
summary(actm6)


############## Do the same for number of vigilant acts ###############

acts1 <- vigilance[, - (44:49)]
acts2 <- acts1[, - (30:42)]
acts3 <- acts2[, - (13:16)]
acts3$Group.ID <- NULL
acts3$No..females <- NULL
acts3$No..males <- NULL
acts3$ID <- NULL
acts3$No..groups <- NULL
acts3$Individual <- NULL
acts3$Time <- NULL
acts3$actse <- NULL
acts3$Location <- NULL
acts3$Group.size <- NULL
acts3$Position.in.group <- NULL

str(acts3)

colnames(acts3)[colnames(acts3)=="No..Vigilant.acts"] <- "vigacts" ## Rename the column

hist(acts3$vigacts)
hist(sqrt(acts3$vigacts))
acts3$vigact.edit <- sqrt(acts3$vigacts)  ## Transform data so more normal

acts3$Region <- as.character(acts3$Region) ## Region 1 is SEQ
acts3$Mob.size <- as.factor(acts3$Mob.size)

summary(a0 <- lmer(vigact.edit ~ Mob.size + Sex + Landuse + RF2day + HPD16 + Distance.to.cover + Season*Region  +(1|Site), 
                   data=acts3))

drop1(a0, test = "Chi")
a1 <- update(a0, ~ . - Landuse)
anova(a1, a0)
summary(a1)
drop1(a1, test = "Chi")
a2 <- update(a1, ~ . - Distance.to.cover)
anova(a1, a2)
summary(a2)
drop1(a2, test = "Chi")
a3 <- update(a2, ~ . -HPD16)
anova(a3, a2)
summary(a3) 
drop1(a3, test = "Chi")
a4 <- update(a3, ~ . -Season*Region)
anova(a4, a3)
summary(a4)
drop1(a4, test="Chi")
a5 <- update(a4, ~ . -RF2day)
anova(a5,a4)
summary(a5)
drop1(a5, test="Chi")
a6 <- update(a5, ~ . - Sex)
anova(a6, a5)
summary(a6) ##### FINAL

## Create graph for number of vigilant acts per min and mob size

acts3$vigact.min <- (acts3$vigacts)/10 # create new column for number of vigilant events per minute

acts3$Region[acts3$Region == "1"] <- "SEQ"
acts3$Region[acts3$Region == "2"] <- "ACT"

acts3$Region <- as.character(acts3$Region) ## Region 1 is SEQ
acts3$Season <- as.character(acts3$Season) 
acts3$Mob.size <- as.integer(acts3$Mob.size)

acts3$Season[acts3$Season == "S"] <- "Summer"
acts3$Season[acts3$Season == "W"] <- "Winter"

ggplot(acts3, aes(x=Mob.size, y=vigact.min, col=Region, shape=Season)) +
  geom_point(position=position_jitter(height=0, width=0.1),size=2.5) + 
  geom_smooth(method=lm, se=FALSE, aes(group=Region)) +
  xlab("Mob size") + ylab("Number of vigilant acts/min") +
  scale_x_continuous(breaks=seq(0,9,1)) +
  scale_color_brewer(palette="Dark2")


## Try with no interaction term

summary(a0 <- lmer(vigact.edit ~ Mob.size + Sex + Landuse + RF2day + HPD16 + Distance.to.cover + Season +Region  +(1|Site), 
                   data=acts3))

drop1(a0, test = "Chi")
a1 <- update(a0, ~ . - Landuse)
anova(a1, a0)
summary(a1)
drop1(a1, test = "Chi")
a2 <- update(a1, ~ . - Distance.to.cover)
anova(a1, a2)
summary(a2)
drop1(a2, test = "Chi")
a3 <- update(a2, ~ . -HPD16)
anova(a3, a2)
summary(a3) 
drop1(a3, test = "Chi")
a4 <- update(a3, ~ . -Sex)
anova(a4, a3)
summary(a4)
drop1(a4, test="Chi")
a5 <- update(a4, ~ . -RF2day)
anova(a5,a4)
summary(a5)
drop1(a5, test="Chi")
a6 <- update(a5, ~ . - Season)
anova(a6, a5)
summary(a6) ##### Final
drop1(a6, test="Chi")
a7 <- update(a6, ~ . -Region)
anova(a7, a6)
summary(a7)